execute_action

Function execute_action 

pub fn execute_action(
    module: &Module,
    request: &ActionRequest,
) -> Result<ActionResult, RuntimeError>
Execute an action against the given module and state.

  1. Find the action (function) in the module
  2. Check preconditions
  3. Extract field assignments from ensures and compute new state
  4. Validate postconditions against new state
  5. Validate invariants against new state